@@ -14,39 +14,38 @@
 #include <interfaces/torrentinterface.h>
 #include <interfaces/trackerslist.h>
 
-#include "bttransferhandler.h"
 #include "bittorrentsettings.h"
-#include "fileview.h"
+#include "bttransferhandler.h"
 #include "chunkdownloadview.h"
-#include "peerview.h"
+#include "fileview.h"
 #include "monitor.h"
+#include "peerview.h"
 #include "trackerview.h"
 #include "webseedstab.h"
 
 #include "kget_debug.h"
 
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KTitleWidget>
 #include <QDialog>
 #include <QGridLayout>
 #include <QTabWidget>
 
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <KTitleWidget>
-
 using namespace kt;
 
-BTAdvancedDetailsWidget::BTAdvancedDetailsWidget(BTTransferHandler * transfer)
+BTAdvancedDetailsWidget::BTAdvancedDetailsWidget(BTTransferHandler *transfer)
     : m_transfer(transfer)
 {
     tc = m_transfer->torrentControl();
 
     init();
 
-    //This updates the widget with the right values
+    // This updates the widget with the right values
     slotTransferChanged(transfer, 0xFFFFFFFF);
-    
-    connect(m_transfer, &TransferHandler::transferChangedEvent,
-            this,       &BTAdvancedDetailsWidget::slotTransferChanged);
+
+    connect(m_transfer, &TransferHandler::transferChangedEvent, this, &BTAdvancedDetailsWidget::slotTransferChanged);
 }
 
 void BTAdvancedDetailsWidget::init()
@@ -56,7 +55,7 @@ void BTAdvancedDetailsWidget::init()
     auto *layout = new QGridLayout();
     auto *titleWidget = new KTitleWidget(this);
     titleWidget->setText(i18n("Advanced Details for %1", m_transfer->source().fileName()));
-    titleWidget->setPixmap(QIcon::fromTheme("dialog-information"));
+    titleWidget->setIcon(QIcon::fromTheme("dialog-information"));
     layout->addWidget(titleWidget);
     tabWidget = new QTabWidget(this);
     layout->addWidget(tabWidget);
@@ -64,11 +63,11 @@ void BTAdvancedDetailsWidget::init()
     file_view = new FileView(this);
     file_view->changeTC(tc, KSharedConfig::openConfig());
     tabWidget->insertTab(0, file_view, QIcon::fromTheme("inode-directory"), i18n("Files"));
-    //peer_view = new PeerView(this);
-    //tabWidget->insertTab(1, peer_view, QIcon::fromTheme("system-users"), i18n("Peers"));
-    //cd_view = new ChunkDownloadView(this);
-    //cd_view->changeTC(tc);
-    //tabWidget->insertTab(2, cd_view, QIcon::fromTheme("preferences-plugin"), i18n("Chunks"));
+    // peer_view = new PeerView(this);
+    // tabWidget->insertTab(1, peer_view, QIcon::fromTheme("system-users"), i18n("Peers"));
+    // cd_view = new ChunkDownloadView(this);
+    // cd_view->changeTC(tc);
+    // tabWidget->insertTab(2, cd_view, QIcon::fromTheme("preferences-plugin"), i18n("Chunks"));
     tracker_view = new TrackerView(this);
     tracker_view->changeTC(tc);
     tabWidget->insertTab(1, tracker_view, QIcon::fromTheme("network-server"), i18n("Trackers"));
@@ -78,7 +77,7 @@ void BTAdvancedDetailsWidget::init()
     monitor = new Monitor(tc, nullptr, nullptr, file_view);
 }
 
-void BTAdvancedDetailsWidget::hideEvent(QHideEvent * event)
+void BTAdvancedDetailsWidget::hideEvent(QHideEvent *event)
 {
     Q_UNUSED(event)
 
@@ -87,26 +86,26 @@ void BTAdvancedDetailsWidget::hideEvent(QHideEvent * event)
     Q_EMIT aboutToClose();
     deleteLater();
 }
- 
-kt::Monitor* BTAdvancedDetailsWidget::torrentMonitor() const
+
+kt::Monitor *BTAdvancedDetailsWidget::torrentMonitor() const
 {
     return monitor;
 }
 
-void BTAdvancedDetailsWidget::slotTransferChanged(TransferHandler * transfer, TransferHandler::ChangesFlags flags)
+void BTAdvancedDetailsWidget::slotTransferChanged(TransferHandler *transfer, TransferHandler::ChangesFlags flags)
 {
-    qCDebug(KGET_DEBUG) << "BTAdvancedDetailsWidget::slotTransferChanged" ;
-    
+    qCDebug(KGET_DEBUG) << "BTAdvancedDetailsWidget::slotTransferChanged";
+
     Q_UNUSED(transfer)
-    
-    if (flags & BTTransfer::Tc_ChunksTotal || flags & BTTransfer::Tc_ChunksDownloaded || flags & BTTransfer::Tc_ChunksExcluded || flags & BTTransfer::Tc_ChunksLeft || flags & Transfer::Tc_DownloadSpeed || flags & Transfer::Tc_UploadSpeed)
-    {
-        //if (tabWidget->currentIndex() == 1)
-        //        peer_view->update();
-        //else if (tabWidget->currentIndex() == 2)
-        //        cd_view->update();
-        /*else */if (tabWidget->currentIndex() == 1)
-                tracker_view->update();
+
+    if (flags & BTTransfer::Tc_ChunksTotal || flags & BTTransfer::Tc_ChunksDownloaded || flags & BTTransfer::Tc_ChunksExcluded
+        || flags & BTTransfer::Tc_ChunksLeft || flags & Transfer::Tc_DownloadSpeed || flags & Transfer::Tc_UploadSpeed) {
+        // if (tabWidget->currentIndex() == 1)
+        //         peer_view->update();
+        // else if (tabWidget->currentIndex() == 2)
+        //         cd_view->update();
+        /*else */ if (tabWidget->currentIndex() == 1)
+            tracker_view->update();
     }
     /*else if (m_transfer->status() == Job::Stopped)
     {
@@ -114,6 +113,3 @@ void BTAdvancedDetailsWidget::slotTransferChanged(TransferHandler * transfer, Tr
         //cd_view->removeAll();
     }*/
 }
-
-
- 
