@@ -15,27 +15,27 @@
 #include <cmath>
 
 #include "kget_debug.h"
-#include <QDebug>
 #include <KLocalizedString>
+#include <QDebug>
 
 #include <QTimer>
 
 Segment::Segment(const QUrl &src, const QPair<KIO::fileoffset_t, KIO::fileoffset_t> &segmentSize, const QPair<int, int> &segmentRange, QObject *parent)
-  : QObject(parent),
-    m_findFilesize((segmentRange.first == -1) && (segmentRange.second == -1)),
-    m_canResume(true),
-    m_status(Stopped),
-    m_currentSegment(segmentRange.first),
-    m_endSegment(segmentRange.second),
-    m_errorCount(0),
-    m_offset(segmentSize.first * segmentRange.first),
-    m_currentSegSize(segmentSize.first),
-    m_bytesWritten(0),
-    m_getJob(nullptr),
-    m_url(src),
-    m_segSize(segmentSize)
+    : QObject(parent)
+    , m_findFilesize((segmentRange.first == -1) && (segmentRange.second == -1))
+    , m_canResume(true)
+    , m_status(Stopped)
+    , m_currentSegment(segmentRange.first)
+    , m_endSegment(segmentRange.second)
+    , m_errorCount(0)
+    , m_offset(segmentSize.first * segmentRange.first)
+    , m_currentSegSize(segmentSize.first)
+    , m_bytesWritten(0)
+    , m_getJob(nullptr)
+    , m_url(src)
+    , m_segSize(segmentSize)
 {
-    //last segment
+    // last segment
     if (m_endSegment - m_currentSegment == 0) {
         m_currentSegSize = m_segSize.second;
     }
@@ -53,8 +53,7 @@ Segment::Segment(const QUrl &src, const QPair<KIO::fileoffset_t, KIO::fileoffset
 
 Segment::~Segment()
 {
-    if (m_getJob)
-    {
+    if (m_getJob) {
         qCDebug(KGET_DEBUG) << "Closing transfer ...";
         m_getJob->kill(KJob::Quietly);
     }
@@ -68,41 +67,38 @@ bool Segment::findingFileSize() const
 bool Segment::createTransfer()
 {
     qCDebug(KGET_DEBUG) << " -- " << m_url;
-    if ( m_getJob )
+    if (m_getJob)
         return false;
 
     m_getJob = KIO::get(m_url, KIO::Reload, KIO::HideProgressInfo);
     m_getJob->suspend();
-    m_getJob->addMetaData( "errorPage", "false" );
-    m_getJob->addMetaData( "AllowCompressedPage", "false" );
-    if (m_offset)
-    {
-        m_canResume = false;//FIXME set m_canResume to false by default!!
-        m_getJob->addMetaData( "resume", KIO::number(m_offset) );
-        connect(m_getJob, &KIO::TransferJob::canResume,
-                 this, &Segment::slotCanResume);
+    m_getJob->addMetaData("errorPage", "false");
+    m_getJob->addMetaData("AllowCompressedPage", "false");
+    if (m_offset) {
+        m_canResume = false; // FIXME set m_canResume to false by default!!
+        m_getJob->addMetaData("resume", KIO::number(m_offset));
+        connect(m_getJob, &KIO::TransferJob::canResume, this, &Segment::slotCanResume);
     }
-    #if 0 //TODO: we disable that code till it's implemented in kdelibs, also we need to think, which settings we should use
+#if 0 // TODO: we disable that code till it's implemented in kdelibs, also we need to think, which settings we should use
     if (Settings::speedLimit())
     {
         m_getJob->addMetaData( "speed-limit", KIO::number(Settings::transferSpeedLimit() * 1024) );
     }
-    #endif
+#endif
     connect(m_getJob, &KJob::totalSize, this, &Segment::slotTotalSize);
-    connect(m_getJob, &KIO::TransferJob::data,
-                 this, &Segment::slotData);
+    connect(m_getJob, &KIO::TransferJob::data, this, &Segment::slotData);
     connect(m_getJob, &KJob::result, this, &Segment::slotResult);
-    connect(m_getJob, &KIO::TransferJob::redirection, this, &Segment::slotRedirection); 
+    connect(m_getJob, &KIO::TransferJob::redirection, this, &Segment::slotRedirection);
     return true;
 }
 
-void Segment::slotRedirection(KIO::Job* , const QUrl &url)
+void Segment::slotRedirection(KIO::Job *, const QUrl &url)
 {
     m_url = url;
     Q_EMIT urlChanged(url);
 }
 
-void Segment::slotCanResume( KIO::Job* job, KIO::filesize_t offset )
+void Segment::slotCanResume(KIO::Job *job, KIO::filesize_t offset)
 {
     Q_UNUSED(job)
     Q_UNUSED(offset)
@@ -137,7 +133,7 @@ void Segment::slotTotalSize(KJob *job, qulonglong size)
     }
 }
 
-bool Segment::startTransfer ()
+bool Segment::startTransfer()
 {
     qCDebug(KGET_DEBUG) << m_url;
     if (!m_getJob) {
@@ -165,32 +161,28 @@ bool Segment::stopTransfer()
     return false;
 }
 
-void Segment::slotResult( KJob *job )
+void Segment::slotResult(KJob *job)
 {
     qCDebug(KGET_DEBUG) << "Job:" << job << m_url << "error:" << job->error();
 
     m_getJob = nullptr;
 
-    //clear the buffer as the download might be moved around
-    if (m_status == Stopped)
-    {
+    // clear the buffer as the download might be moved around
+    if (m_status == Stopped) {
         m_buffer.clear();
     }
-    if ( !m_buffer.isEmpty() )
-    {
+    if (!m_buffer.isEmpty()) {
         if (m_findFilesize && !job->error()) {
             qCDebug(KGET_DEBUG) << "Looping until write the buffer ..." << m_url;
             slotWriteRest();
             return;
         }
     }
-    if (!m_totalBytesLeft  && !m_findFilesize)
-    {
+    if (!m_totalBytesLeft && !m_findFilesize) {
         setStatus(Finished);
         return;
     }
-    if( m_status == Killed )
-    {
+    if (m_status == Killed) {
         return;
     }
     if (job->error() && (m_status == Running)) {
@@ -198,39 +190,35 @@ void Segment::slotResult( KJob *job )
     }
 }
 
-void Segment::slotData(KIO::Job *, const QByteArray& _data)
+void Segment::slotData(KIO::Job *, const QByteArray &_data)
 {
     // Check if the transfer allows resuming...
-    if (m_offset && !m_canResume)
-    {
+    if (m_offset && !m_canResume) {
         qCDebug(KGET_DEBUG) << m_url << "does not allow resuming.";
         stopTransfer();
-        setStatus(Killed, false );
+        setStatus(Killed, false);
         const QString errorText = KIO::buildErrorString(KIO::ERR_CANNOT_RESUME, m_url.toString());
         Q_EMIT error(this, errorText, Transfer::Log_Warning);
         return;
     }
 
     m_buffer.append(_data);
-    if (!m_findFilesize && m_totalBytesLeft && static_cast<uint>(m_buffer.size()) >= m_totalBytesLeft)
-    {
-        qCDebug(KGET_DEBUG) << "Segment::slotData() buffer full. Stopping transfer...";//TODO really stop it? is this even needed?
+    if (!m_findFilesize && m_totalBytesLeft && static_cast<uint>(m_buffer.size()) >= m_totalBytesLeft) {
+        qCDebug(KGET_DEBUG) << "Segment::slotData() buffer full. Stopping transfer..."; // TODO really stop it? is this even needed?
         if (m_getJob) {
             m_getJob->kill(KJob::Quietly);
             m_getJob = nullptr;
         }
         m_buffer.truncate(m_totalBytesLeft);
         slotWriteRest();
-    }
-    else
-    { 
-    /* 
-     write to the local file only if the buffer has more than 100kbytes
-     this hack try to avoid too much cpu usage. it seems to be due KIO::Filejob
-     so remove it when it works property
-    */
-    if (m_buffer.size() > MultiSegKioSettings::saveSegSize() * 1024)
-        writeBuffer();
+    } else {
+        /*
+         write to the local file only if the buffer has more than 100kbytes
+         this hack try to avoid too much cpu usage. it seems to be due KIO::Filejob
+         so remove it when it works property
+        */
+        if (m_buffer.size() > MultiSegKioSettings::saveSegSize() * 1024)
+            writeBuffer();
     }
 }
 
@@ -255,14 +243,14 @@ bool Segment::writeBuffer()
         qCDebug(KGET_DEBUG) << "Segment::writeBuffer() updating segment record of job:" << m_getJob << "--" << m_totalBytesLeft << "bytes left";
     }
 
-    //finding filesize, so no segments defined yet
+    // finding filesize, so no segments defined yet
     if (m_findFilesize) {
         return worked;
     }
 
-    //check which segments have been finished
+    // check which segments have been finished
     bool finished = false;
-    //m_currentSegSize being smaller than 1 means that at least one segment has been finished
+    // m_currentSegSize being smaller than 1 means that at least one segment has been finished
     while (m_currentSegSize <= 0 && !finished) {
         finished = (m_currentSegment == m_endSegment);
         Q_EMIT finishedSegment(this, m_currentSegment, finished);
@@ -324,20 +312,17 @@ int Segment::countUnfinishedSegments() const
 
 QPair<int, int> Segment::split()
 {
-    if (m_getJob)
-    {
+    if (m_getJob) {
         m_getJob->suspend();
     }
 
     QPair<int, int> freed = QPair<int, int>(-1, -1);
     const int free = std::ceil((countUnfinishedSegments() + 1) / static_cast<double>(2));
 
-    if (!free)
-    {
+    if (!free) {
         qCDebug(KGET_DEBUG) << "None freed, start:" << m_currentSegment << "end:" << m_endSegment;
 
-        if (m_getJob)
-        {
+        if (m_getJob) {
             m_getJob->resume();
         }
         return freed;
@@ -349,14 +334,12 @@ QPair<int, int> Segment::split()
     m_endSegment = newEnd;
     m_totalBytesLeft -= m_segSize.first * (free - 1) + m_segSize.second;
 
-    //end changed, so in any case the lastSegSize should be the normal segSize
-    if (free)
-    {
+    // end changed, so in any case the lastSegSize should be the normal segSize
+    if (free) {
         m_segSize.second = m_segSize.first;
     }
 
-    if (m_getJob)
-    {
+    if (m_getJob) {
         m_getJob->resume();
     }
     return freed;
@@ -373,5 +356,3 @@ bool Segment::merge(const QPair<KIO::fileoffset_t, KIO::fileoffset_t> &segmentSi
 
     return false;
 }
-
-
