@@ -1,21 +1,21 @@
 /***************************************************************************
-*   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "mirrormodel.h"
 
@@ -28,48 +28,38 @@
 #include <KLocalizedString>
 
 MirrorDelegate::MirrorDelegate(QObject *parent)
-  : QStyledItemDelegate(parent),
-    m_countrySort(nullptr)
+    : QStyledItemDelegate(parent)
+    , m_countrySort(nullptr)
 {
 }
 
 MirrorDelegate::MirrorDelegate(QSortFilterProxyModel *countrySort, QObject *parent)
-  : QStyledItemDelegate(parent),
-    m_countrySort(countrySort)
+    : QStyledItemDelegate(parent)
+    , m_countrySort(countrySort)
 {
-
 }
 
 QWidget *MirrorDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option)
 
-    if (index.isValid())
-    {
-        if (index.column() == MirrorItem::Url)
-        {
+    if (index.isValid()) {
+        if (index.column() == MirrorItem::Url) {
             auto *line = new KLineEdit(parent);
 
             return line;
-        }
-        else if (index.column() == MirrorItem::Connections)
-        {
+        } else if (index.column() == MirrorItem::Connections) {
             auto *numConnections = new QSpinBox(parent);
             numConnections->setRange(0, 20);
 
             return numConnections;
-        }
-        else if (index.column() == MirrorItem::Priority)
-        {
+        } else if (index.column() == MirrorItem::Priority) {
             auto *priority = new QSpinBox(parent);
             priority->setRange(0, 999999);
 
             return priority;
-        }
-        else if (index.column() == MirrorItem::Country)
-        {
-            if (m_countrySort)
-            {
+        } else if (index.column() == MirrorItem::Country) {
+            if (m_countrySort) {
                 auto *countrySort = new QComboBox(parent);
                 countrySort->setModel(m_countrySort);
 
@@ -85,19 +75,19 @@ void MirrorDelegate::setEditorData(QWidget *editor, const QModelIndex &index) co
 {
     if (index.isValid() && editor) {
         if (index.column() == MirrorItem::Url) {
-            auto *line = static_cast<KLineEdit*>(editor);
+            auto *line = static_cast<KLineEdit *>(editor);
             const QUrl url = index.data(Qt::EditRole).toUrl();
             line->setUrl(url);
         } else if (index.column() == MirrorItem::Connections) {
-            auto *numConnections = static_cast<QSpinBox*>(editor);
+            auto *numConnections = static_cast<QSpinBox *>(editor);
             const int num = index.data(Qt::EditRole).toInt();
             numConnections->setValue(num);
         } else if (index.column() == MirrorItem::Priority) {
-            auto *priority = static_cast<QSpinBox*>(editor);
+            auto *priority = static_cast<QSpinBox *>(editor);
             const int num = index.data(Qt::EditRole).toInt();
             priority->setValue(num);
         } else if (index.column() == MirrorItem::Country) {
-            auto *countrySort = static_cast<QComboBox*>(editor);
+            auto *countrySort = static_cast<QComboBox *>(editor);
             const QString countryCode = index.data(Qt::EditRole).toString();
             const int indexCountrySort = countrySort->findData(countryCode);
             countrySort->setCurrentIndex(indexCountrySort);
@@ -107,29 +97,20 @@ void MirrorDelegate::setEditorData(QWidget *editor, const QModelIndex &index) co
 
 void MirrorDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    if (index.isValid() && editor && model)
-    {
-        if (index.column() == MirrorItem::Url)
-        {
-            auto *line = static_cast<KLineEdit*>(editor);
-            if (!line->text().isEmpty())
-            {
+    if (index.isValid() && editor && model) {
+        if (index.column() == MirrorItem::Url) {
+            auto *line = static_cast<KLineEdit *>(editor);
+            if (!line->text().isEmpty()) {
                 model->setData(index, line->text());
             }
-        }
-        else if (index.column() == MirrorItem::Connections)
-        {
-            auto *numConnections = static_cast<QSpinBox*>(editor);
+        } else if (index.column() == MirrorItem::Connections) {
+            auto *numConnections = static_cast<QSpinBox *>(editor);
             model->setData(index, numConnections->value());
-        }
-        else if (index.column() == MirrorItem::Priority)
-        {
-            auto *priority = static_cast<QSpinBox*>(editor);
+        } else if (index.column() == MirrorItem::Priority) {
+            auto *priority = static_cast<QSpinBox *>(editor);
             model->setData(index, priority->value());
-        }
-        else if (index.column() == MirrorItem::Country)
-        {
-            auto *countrySort = static_cast<QComboBox*>(editor);
+        } else if (index.column() == MirrorItem::Country) {
+            auto *countrySort = static_cast<QComboBox *>(editor);
             const QString countryCode = countrySort->itemData(countrySort->currentIndex()).toString();
             model->setData(index, countryCode);
         }
@@ -144,16 +125,15 @@ void MirrorDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionVie
 
 QSize MirrorDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    //make the sizeHint a little bit nicer to have more beautiful editors
+    // make the sizeHint a little bit nicer to have more beautiful editors
     QSize hint;
     hint.setWidth(QStyledItemDelegate::sizeHint(option, index).width());
     hint.setHeight(option.fontMetrics.height() + 7);
     return hint;
 }
 
-
 MirrorProxyModel::MirrorProxyModel(QObject *parent)
-  : QSortFilterProxyModel(parent)
+    : QSortFilterProxyModel(parent)
 {
 }
 
@@ -166,84 +146,55 @@ bool MirrorProxyModel::lessThan(const QModelIndex &left, const QModelIndex &righ
     } else if (left.column() == MirrorItem::Priority) {
         const int leftData = sourceModel()->data(left, Qt::UserRole).toInt();
         const int rightData = sourceModel()->data(right, Qt::UserRole).toInt();
-        return (!leftData ? true : (leftData > rightData) && rightData);//0 is always smallest, otherwise larger is smaller
+        return (!leftData ? true : (leftData > rightData) && rightData); // 0 is always smallest, otherwise larger is smaller
     }
 
     return QSortFilterProxyModel::lessThan(left, right);
 }
 
-
 MirrorItem::MirrorItem()
-  : m_checked(Qt::Unchecked),
-    m_numConnections(0),
-    m_priority(0)
+    : m_checked(Qt::Unchecked)
+    , m_numConnections(0)
+    , m_priority(0)
 {
 }
 
 QVariant MirrorItem::data(int column, int role) const
 {
-    if (column == MirrorItem::Used)
-    {
-        if (role == Qt::CheckStateRole)
-        {
+    if (column == MirrorItem::Used) {
+        if (role == Qt::CheckStateRole) {
             return m_checked;
         }
-    }
-    else if (column == MirrorItem::Url)
-    {
-        if (role == Qt::DisplayRole)
-        {
+    } else if (column == MirrorItem::Url) {
+        if (role == Qt::DisplayRole) {
             return m_url.toString();
-        }
-        else if ((role == Qt::UserRole) || (role == Qt::EditRole))
-        {
+        } else if ((role == Qt::UserRole) || (role == Qt::EditRole)) {
             return QVariant(m_url);
         }
-    }
-    else if (column == MirrorItem::Connections)
-    {
-        if (role == Qt::DisplayRole)
-        {
-            if (m_numConnections)
-            {
+    } else if (column == MirrorItem::Connections) {
+        if (role == Qt::DisplayRole) {
+            if (m_numConnections) {
                 return m_numConnections;
-            }
-            else
-            {
+            } else {
                 return i18n("not specified");
             }
-        }
-        else if ((role == Qt::EditRole) || (role == Qt::UserRole))
-        {
+        } else if ((role == Qt::EditRole) || (role == Qt::UserRole)) {
             return m_numConnections;
         }
-    }
-    else if (column == MirrorItem::Priority)
-    {
-        if (role == Qt::DisplayRole)
-        {
-            if (m_priority)
-            {
+    } else if (column == MirrorItem::Priority) {
+        if (role == Qt::DisplayRole) {
+            if (m_priority) {
                 return m_priority;
-            }
-            else
-            {
+            } else {
                 return i18n("not specified");
             }
-        }
-        else if ((role == Qt::EditRole) || (role == Qt::UserRole))
-        {
+        } else if ((role == Qt::EditRole) || (role == Qt::UserRole)) {
             return m_priority;
         }
-    }
-    else if (column == MirrorItem::Country)
-    {
-        if (role == Qt::DisplayRole)
-        {
+    } else if (column == MirrorItem::Country) {
+        if (role == Qt::DisplayRole) {
             return m_countryName;
-        }
-        else if ((role == Qt::UserRole) || (role == Qt::EditRole))
-        {
+        } else if ((role == Qt::UserRole) || (role == Qt::EditRole)) {
             return m_countryCode;
         }
     }
@@ -254,24 +205,15 @@ QVariant MirrorItem::data(int column, int role) const
 Qt::ItemFlags MirrorItem::flags(int column) const
 {
     Qt::ItemFlags flags = Qt::ItemIsEnabled | Qt::ItemIsSelectable;
-    if (column == MirrorItem::Used)
-    {
+    if (column == MirrorItem::Used) {
         flags |= Qt::ItemIsUserCheckable;
-    }
-    else if (column == MirrorItem::Url)
-    {
+    } else if (column == MirrorItem::Url) {
         flags |= Qt::ItemIsEditable;
-    }
-    else if (column == MirrorItem::Connections)
-    {
+    } else if (column == MirrorItem::Connections) {
         flags |= Qt::ItemIsEditable;
-    }
-    else if (column == MirrorItem::Priority)
-    {
+    } else if (column == MirrorItem::Priority) {
         flags |= Qt::ItemIsEditable;
-    }
-    else if (column == MirrorItem::Country)
-    {
+    } else if (column == MirrorItem::Country) {
         flags |= Qt::ItemIsEditable;
     }
 
@@ -280,41 +222,28 @@ Qt::ItemFlags MirrorItem::flags(int column) const
 
 bool MirrorItem::setData(int column, const QVariant &value, int role)
 {
-    if ((column == MirrorItem::Used) && (role == Qt::CheckStateRole))
-    {
+    if ((column == MirrorItem::Used) && (role == Qt::CheckStateRole)) {
         m_checked = static_cast<Qt::CheckState>(value.toInt());
         return true;
-    }
-    else if ((column == MirrorItem::Url) && (role == Qt::EditRole))
-    {
+    } else if ((column == MirrorItem::Url) && (role == Qt::EditRole)) {
         QUrl url;
-        if (value.type() == QVariant::Url)
-        {
+        if (value.type() == QVariant::Url) {
             url = QUrl(value.toUrl());
-        }
-        else if (value.type() == QVariant::String)
-        {
+        } else if (value.type() == QVariant::String) {
             url = QUrl(value.toString());
         }
 
-        if (!url.isEmpty())
-        {
+        if (!url.isEmpty()) {
             m_url = url;
             return true;
         }
-    }
-    else if ((column == MirrorItem::Connections) && (role == Qt::EditRole))
-    {
+    } else if ((column == MirrorItem::Connections) && (role == Qt::EditRole)) {
         m_numConnections = value.toInt();
         return true;
-    }
-    else if ((column == MirrorItem::Priority) && (role == Qt::EditRole))
-    {
+    } else if ((column == MirrorItem::Priority) && (role == Qt::EditRole)) {
         m_priority = value.toInt();
         return true;
-    }
-    else if ((column == MirrorItem::Country) && (role == Qt::EditRole))
-    {
+    } else if ((column == MirrorItem::Country) && (role == Qt::EditRole)) {
         m_countryCode = value.toString();
         m_countryName = KCountry::fromAlpha2(m_countryCode).name();
         return true;
@@ -323,9 +252,8 @@ bool MirrorItem::setData(int column, const QVariant &value, int role)
     return false;
 }
 
-
 MirrorModel::MirrorModel(QObject *parent)
-: QAbstractTableModel(parent)
+    : QAbstractTableModel(parent)
 {
 }
 
@@ -336,20 +264,16 @@ MirrorModel::~MirrorModel()
 
 int MirrorModel::rowCount(const QModelIndex &index) const
 {
-    if (!index.isValid())
-    {
+    if (!index.isValid()) {
         return m_data.count();
-    }
-    else
-    {
+    } else {
         return 0;
     }
 }
 
 int MirrorModel::columnCount(const QModelIndex &index) const
 {
-    if (index.isValid())
-    {
+    if (index.isValid()) {
         return 0;
     }
 
@@ -404,8 +328,7 @@ bool MirrorModel::setData(const QModelIndex &index, const QVariant &value, int r
     }
 
     const bool changed = m_data.at(index.row())->setData(index.column(), value, role);
-    if (changed)
-    {
+    if (changed) {
         Q_EMIT dataChanged(index, index);
     }
     return changed;
@@ -413,14 +336,12 @@ bool MirrorModel::setData(const QModelIndex &index, const QVariant &value, int r
 
 bool MirrorModel::removeRows(int row, int count, const QModelIndex &parent)
 {
-    if (parent.isValid() || (row < 0) || (count < 1) || (row + count > rowCount()))
-    {
+    if (parent.isValid() || (row < 0) || (count < 1) || (row + count > rowCount())) {
         return false;
     }
 
     beginRemoveRows(parent, row, row + count - 1);
-    while (count)
-    {
+    while (count) {
         MirrorItem *item = m_data[row];
         m_data.removeAt(row);
         delete item;
@@ -433,16 +354,13 @@ bool MirrorModel::removeRows(int row, int count, const QModelIndex &parent)
 
 void MirrorModel::addMirror(const QUrl &url, int numConnections, int priority, const QString &countryCode)
 {
-    if (!url.isValid())
-    {
+    if (!url.isValid()) {
         return;
     }
 
-    for (int i = 0; i < rowCount(); ++i)
-    {
-        //exists already, so remove the row
-        if (QUrl(m_data.at(i)->data(MirrorItem::Url).toString()) == url)
-        {
+    for (int i = 0; i < rowCount(); ++i) {
+        // exists already, so remove the row
+        if (QUrl(m_data.at(i)->data(MirrorItem::Url).toString()) == url) {
             removeRow(i);
             break;
         }
@@ -453,7 +371,7 @@ void MirrorModel::addMirror(const QUrl &url, int numConnections, int priority, c
 
     auto *item = new MirrorItem;
     m_data.append(item);
-    item->setData(MirrorItem::Used, Qt::Checked, Qt::CheckStateRole);//every newly added mirror is set to checked automatically
+    item->setData(MirrorItem::Used, Qt::Checked, Qt::CheckStateRole); // every newly added mirror is set to checked automatically
     item->setData(MirrorItem::Url, QVariant(url));
     item->setData(MirrorItem::Connections, numConnections);
     item->setData(MirrorItem::Priority, priority);
@@ -462,15 +380,14 @@ void MirrorModel::addMirror(const QUrl &url, int numConnections, int priority, c
     Q_EMIT endInsertRows();
 }
 
-void MirrorModel::setMirrors(const QHash<QUrl, QPair<bool, int> > &mirrors)
+void MirrorModel::setMirrors(const QHash<QUrl, QPair<bool, int>> &mirrors)
 {
     beginResetModel();
     removeRows(0, rowCount());
 
-    QHash<QUrl, QPair<bool, int> >::const_iterator it;
-    QHash<QUrl, QPair<bool, int> >::const_iterator itEnd = mirrors.constEnd();
-    for (it = mirrors.constBegin(); it != itEnd; ++it)
-    {
+    QHash<QUrl, QPair<bool, int>>::const_iterator it;
+    QHash<QUrl, QPair<bool, int>>::const_iterator itEnd = mirrors.constEnd();
+    for (it = mirrors.constBegin(); it != itEnd; ++it) {
         auto *item = new MirrorItem;
         item->setData(MirrorItem::Url, QVariant(it.key()));
         Qt::CheckState state = (*it).first ? Qt::Checked : Qt::Unchecked;
@@ -482,16 +399,13 @@ void MirrorModel::setMirrors(const QHash<QUrl, QPair<bool, int> > &mirrors)
     endResetModel();
 }
 
-QHash<QUrl, QPair<bool, int> > MirrorModel::availableMirrors() const
+QHash<QUrl, QPair<bool, int>> MirrorModel::availableMirrors() const
 {
-    QHash<QUrl, QPair<bool, int> > mirrors;
-    foreach (MirrorItem *item, m_data)
-    {
+    QHash<QUrl, QPair<bool, int>> mirrors;
+    foreach (MirrorItem *item, m_data) {
         bool used = (item->data(MirrorItem::Used, Qt::CheckStateRole).toInt() == Qt::Checked) ? true : false;
         const QUrl url = QUrl(item->data(MirrorItem::Url).toString());
         mirrors[url] = QPair<bool, int>(used, item->data(MirrorItem::Connections, Qt::UserRole).toInt());
     }
     return mirrors;
 }
-
-
