@@ -1,24 +1,23 @@
 /***************************************************************************
-*   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "mirrorsettings.h"
-#include "mirrormodel.h"
 #include "core/transferhandler.h"
 
 #include <QSortFilterProxyModel>
@@ -27,17 +26,17 @@
 #include <KStandardGuiItem>
 
 MirrorAddDlg::MirrorAddDlg(MirrorModel *model, QWidget *parent, Qt::WindowFlags flags)
-  : QDialog(parent, flags),
-    m_model(model),
-    m_countryModel(nullptr)
+    : QDialog(parent, flags)
+    , m_model(model)
+    , m_countryModel(nullptr)
 {
     init();
 }
 
 MirrorAddDlg::MirrorAddDlg(MirrorModel *model, QSortFilterProxyModel *countryModel, QWidget *parent, Qt::WindowFlags flags)
-  : QDialog(parent, flags),
-    m_model(model),
-    m_countryModel(countryModel)
+    : QDialog(parent, flags)
+    , m_model(model)
+    , m_countryModel(countryModel)
 {
     init();
 }
@@ -55,8 +54,7 @@ void MirrorAddDlg::init()
     setWindowTitle(i18n("Add mirror"));
     ui.setupUi(this);
 
-    if (m_countryModel)
-    {
+    if (m_countryModel) {
         ui.location->setModel(m_countryModel);
         ui.location->setCurrentIndex(-1);
     }
@@ -72,25 +70,24 @@ void MirrorAddDlg::init()
 
 void MirrorAddDlg::showItem(MirrorItem::DataType type, bool show)
 {
-    switch (type)
-    {
-        case MirrorItem::Connections:
-            ui.labelConnections->setVisible(show);
-            ui.numConnections->setVisible(show);
-            break;
+    switch (type) {
+    case MirrorItem::Connections:
+        ui.labelConnections->setVisible(show);
+        ui.numConnections->setVisible(show);
+        break;
 
-        case MirrorItem::Priority:
-            ui.labelPriority->setVisible(show);
-            ui.priority->setVisible(show);
-            break;
+    case MirrorItem::Priority:
+        ui.labelPriority->setVisible(show);
+        ui.priority->setVisible(show);
+        break;
 
-        case MirrorItem::Country:
-            ui.labelLocation->setVisible(show);
-            ui.location->setVisible(show);
-            break;
+    case MirrorItem::Country:
+        ui.labelLocation->setVisible(show);
+        ui.location->setVisible(show);
+        break;
 
-        default:
-            break;
+    default:
+        break;
     }
     update();
 }
@@ -99,8 +96,7 @@ void MirrorAddDlg::updateButton(const QString &text)
 {
     bool enabled = false;
     QUrl url(text);
-    if (url.isValid() && !url.scheme().isEmpty() && !url.path().isEmpty())
-    {
+    if (url.isValid() && !url.scheme().isEmpty() && !url.path().isEmpty()) {
         enabled = true;
     }
     ui.buttonBox->button(QDialogButtonBox::Yes)->setEnabled(enabled);
@@ -112,17 +108,16 @@ void MirrorAddDlg::addMirror()
     const int priority = ui.priority->isVisible() ? ui.priority->value() : 0;
     const QString countryCode = ui.location->itemData(ui.location->currentIndex()).toString();
     m_model->addMirror(QUrl(ui.url->text()), numConnections, priority, countryCode);
-    if (m_countryModel)
-    {
+    if (m_countryModel) {
         ui.location->setCurrentIndex(-1);
     }
     this->accept();
 }
 
 MirrorSettings::MirrorSettings(QWidget *parent, TransferHandler *handler, const QUrl &file)
-  : KGetSaveSizeDialog("MirrorSettings", parent),
-    m_transfer(handler),
-    m_file(file)
+    : KGetSaveSizeDialog("MirrorSettings", parent)
+    , m_transfer(handler)
+    , m_file(file)
 {
     m_model = new MirrorModel(this);
     m_model->setMirrors(m_transfer->availableMirrors(m_file));
@@ -147,7 +142,7 @@ MirrorSettings::MirrorSettings(QWidget *parent, TransferHandler *handler, const
     connect(this, &MirrorSettings::finished, this, &MirrorSettings::save);
 
     setWindowTitle(i18n("Modify the used mirrors"));
-    
+
     connect(ui.closeButton, &QPushButton::clicked, this, &QDialog::accept);
 }
 
@@ -181,5 +176,3 @@ void MirrorSettings::save()
 {
     m_transfer->setAvailableMirrors(m_file, m_model->availableMirrors());
 }
-
-
